summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NotationView.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-19 11:40:46 -0600
committerTimothy Pearson <[email protected]>2011-12-19 11:40:46 -0600
commit97f1c43c867725d49f3943a68ef08d7e71767e99 (patch)
treeece35be847c1fcc581a6db7b3d9fc6aa497590af /src/gui/editors/notation/NotationView.cpp
parentef13416bfc43e51ef4e20919e0fab81ae05e0fe2 (diff)
downloadrosegarden-97f1c43c867725d49f3943a68ef08d7e71767e99.tar.gz
rosegarden-97f1c43c867725d49f3943a68ef08d7e71767e99.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'src/gui/editors/notation/NotationView.cpp')
-rw-r--r--src/gui/editors/notation/NotationView.cpp98
1 files changed, 49 insertions, 49 deletions
diff --git a/src/gui/editors/notation/NotationView.cpp b/src/gui/editors/notation/NotationView.cpp
index 6901135..ece3e36 100644
--- a/src/gui/editors/notation/NotationView.cpp
+++ b/src/gui/editors/notation/NotationView.cpp
@@ -755,9 +755,9 @@ NotationView::NotationView(RosegardenGUIDoc *doc,
slotSetPointerPosition(doc->getComposition().getPosition());
setCurrentSelection(0, false, true);
slotUpdateInsertModeStatus();
- m_chordNameRuler->tqrepaint();
- m_tempoRuler->tqrepaint();
- m_rawNoteRuler->tqrepaint();
+ m_chordNameRuler->repaint();
+ m_tempoRuler->repaint();
+ m_rawNoteRuler->repaint();
m_inhibitRefresh = false;
// slotCheckRendered(0, getCanvasView()->visibleWidth());
@@ -1341,7 +1341,7 @@ void NotationView::positionPages()
haveBackground = true;
}
// we're happy to ignore errors from this one:
- deskBackground.load(TQString("%1/misc/bg-desktop.xpm").tqarg(pixmapDir));
+ deskBackground.load(TQString("%1/misc/bg-desktop.xpm").arg(pixmapDir));
}
int pageWidth = getPageWidth();
@@ -1389,7 +1389,7 @@ void NotationView::positionPages()
int w = pageWidth - leftMargin / 2;
int h = pageHeight;
- TQString str = TQString("%1").tqarg(page + 1);
+ TQString str = TQString("%1").arg(page + 1);
TQCanvasText *text = new TQCanvasText(str, pageNumberFont, canvas());
text->setX(m_leftGutter + pageWidth * page + pageWidth - pageNumberMetrics.width(str) - leftMargin);
text->setY(y + h - pageNumberMetrics.descent() - topMargin);
@@ -1557,9 +1557,9 @@ void NotationView::setupActions()
KToggleAction *spacingAction =
new KToggleAction
- (TQString("%1%").tqarg(*i), 0, TQT_TQOBJECT(this),
+ (TQString("%1%").arg(*i), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotChangeSpacingFromAction()),
- actionCollection(), TQString("spacing_%1").tqarg(*i).ascii());
+ actionCollection(), TQString("spacing_%1").arg(*i).ascii());
spacingAction->setExclusiveGroup("spacing");
spacingAction->setChecked(*i == defaultSpacing);
@@ -1577,7 +1577,7 @@ void NotationView::setupActions()
for (std::vector<int>::iterator i = proportions.begin();
i != proportions.end(); ++i) {
- TQString name = TQString("%1%").tqarg(*i);
+ TQString name = TQString("%1%").arg(*i);
if (*i == 0)
name = i18n("None");
@@ -1585,7 +1585,7 @@ void NotationView::setupActions()
new KToggleAction
(name, 0, TQT_TQOBJECT(this),
TQT_SLOT(slotChangeProportionFromAction()),
- actionCollection(), TQString("proportion_%1").tqarg(*i).ascii());
+ actionCollection(), TQString("proportion_%1").arg(*i).ascii());
proportionAction->setExclusiveGroup("proportion");
proportionAction->setChecked(*i == defaultProportion);
@@ -2263,7 +2263,7 @@ void NotationView::setupActions()
for (int i = 0; i <= 5; ++i) {
new KAction(slashTitles[i], 0, TQT_TQOBJECT(this),
TQT_SLOT(slotAddSlashes()), actionCollection(),
- TQString("slashes_%1").tqarg(i).ascii());
+ TQString("slashes_%1").arg(i).ascii());
}
new KAction(ClefInsertionCommand::getGlobalName(), 0, TQT_TQOBJECT(this),
@@ -2546,7 +2546,7 @@ NotationView::setupFontSizeMenu(std::string oldFontName)
for (unsigned int i = 0; i < sizes.size(); ++i) {
KAction *action =
actionCollection()->action
- (TQString("note_font_size_%1").tqarg(sizes[i]).ascii());
+ (TQString("note_font_size_%1").arg(sizes[i]).ascii());
m_fontSizeActionMenu->remove
(action);
@@ -2560,7 +2560,7 @@ NotationView::setupFontSizeMenu(std::string oldFontName)
for (unsigned int i = 0; i < sizes.size(); ++i) {
- TQString actionName = TQString("note_font_size_%1").tqarg(sizes[i]);
+ TQString actionName = TQString("note_font_size_%1").arg(sizes[i]);
KToggleAction *sizeAction = dynamic_cast<KToggleAction *>
(actionCollection()->action(actionName.ascii()));
@@ -3008,7 +3008,7 @@ bool NotationView::applyLayout(int staffNo, timeT startTime, timeT endTime)
if (staffNo >= 0 && (int)i != staffNo)
continue;
- slotSetOperationNameAndStatus(i18n("Laying out staff %1...").tqarg(i + 1));
+ slotSetOperationNameAndStatus(i18n("Laying out staff %1...").arg(i + 1));
ProgressDialog::processEvents();
m_htqlayout->resetStaff(*m_staffs[i], startTime, endTime);
@@ -3194,7 +3194,7 @@ void NotationView::setCurrentSelection(EventSelection* s, bool preview,
getLinedStaff(segment)->positionElements(std::min(startA, startB),
std::max(endA, endB));
} else {
// mark refresh status and then request a tqrepaint
segment.getRefreshStatus
(m_segmentsRefreshStatusIds
[getLinedStaff(segment)->getId()]).
@@ -3211,7 +3211,7 @@ void NotationView::setCurrentSelection(EventSelection* s, bool preview,
getLinedStaff(s->getSegment())->positionElements(startB, endB);
} else {
// mark refresh status and then request a tqrepaint
oldSelection->getSegment().getRefreshStatus
(m_segmentsRefreshStatusIds
@@ -3745,7 +3745,7 @@ NotationView::updateThumbnails(bool complete)
int w = pageWidth - leftMargin / 2;
int h = pageHeight;
- TQString str = TQString("%1").tqarg(page + 1);
+ TQString str = TQString("%1").arg(page + 1);
thumbPainter.drawRect(x / thumbScale, y / thumbScale,
w / thumbScale, h / thumbScale);
@@ -3944,7 +3944,7 @@ void NotationView::readjustCanvasSize()
}
}
- // Give a correct vertical tqalignment to track headers
+ // Give a correct vertical alignment to track headers
if ((m_pageMode == LinedStaff::LinearMode) && m_showHeadersGroup) {
m_headersGroupView->setContentsPos(0, getCanvasView()->contentsY());
}
@@ -4067,7 +4067,7 @@ void NotationView::initActionDataMaps()
(NotationStrings::getReferenceName(Note(type, 0), false));
TQString shortName(TQString("change_%1%2")
- .tqarg(notationOnly ? "notation_" : "").tqarg(refName));
+ .arg(notationOnly ? "notation_" : "").arg(refName));
shortName.replace(TQRegExp("-"), "_");
TQString titleName
@@ -4095,7 +4095,7 @@ void NotationView::initActionDataMaps()
Mark mark = marks[i];
TQString markName(strtoqstr(mark));
- TQString actionName = TQString("add_%1").tqarg(markName);
+ TQString actionName = TQString("add_%1").arg(markName);
m_markActionDataMap->insert
(actionName, new MarkActionData
@@ -4162,7 +4162,7 @@ void NotationView::setupProgress(ProgressDialog* dialog)
void NotationView::slotSetOperationNameAndStatus(TQString name)
{
emit setOperationName(name);
- statusBar()->changeItem(TQString(" %1").tqarg(name),
+ statusBar()->changeItem(TQString(" %1").arg(name),
KTmpStatusMsg::getDefaultId());
}
@@ -4203,18 +4203,18 @@ void NotationView::updateViewCaption()
trackPosition = track->getPosition();
// std::cout << std::endl << std::endl << std::endl << "DEBUG TITLE BAR: " << getDocument()->getTitle() << std::endl << std::endl << std::endl;
setCaption(i18n("%1 - Segment Track #%2 - Notation")
- .tqarg(getDocument()->getTitle())
- .tqarg(trackPosition + 1));
+ .arg(getDocument()->getTitle())
+ .arg(trackPosition + 1));
} else if (m_segments.size() == getDocument()->getComposition().getNbSegments()) {
setCaption(i18n("%1 - All Segments - Notation")
- .tqarg(getDocument()->getTitle()));
+ .arg(getDocument()->getTitle()));
} else {
setCaption(i18n("%1 - Segment - Notation", "%1 - %n Segments - Notation", m_segments.size())
- .tqarg(getDocument()->getTitle()));
+ .arg(getDocument()->getTitle()));
}
}
@@ -4238,15 +4238,15 @@ NotationView::slotUpdateInsertModeStatus()
TQString message;
if (isInTripletMode()) {
- message = i18n("%1 %2").tqarg(message).tqarg(tripletMessage);
+ message = i18n("%1 %2").arg(message).arg(tripletMessage);
}
if (isInChordMode()) {
- message = i18n("%1 %2").tqarg(message).tqarg(chordMessage);
+ message = i18n("%1 %2").arg(message).arg(chordMessage);
}
if (isInGraceMode()) {
- message = i18n("%1 %2").tqarg(message).tqarg(graceMessage);
+ message = i18n("%1 %2").arg(message).arg(graceMessage);
}
m_insertModeLabel->setText(message);
@@ -4317,7 +4317,7 @@ NotationView::slotChangeSpacingFromAction()
} else {
KMessageBox::sorry
- (this, i18n("Unknown spacing action %1").tqarg(name));
+ (this, i18n("Unknown spacing action %1").arg(name));
}
}
@@ -4332,7 +4332,7 @@ NotationView::slotChangeSpacing(int spacing)
// m_spacingSlider->setSize(spacing);
KToggleAction *action = dynamic_cast<KToggleAction *>
- (actionCollection()->action(TQString("spacing_%1").tqarg(spacing).ascii()));
+ (actionCollection()->action(TQString("spacing_%1").arg(spacing).ascii()));
if (action)
action->setChecked(true);
else {
@@ -4375,7 +4375,7 @@ NotationView::slotChangeProportionFromAction()
} else {
KMessageBox::sorry
- (this, i18n("Unknown proportion action %1").tqarg(name));
+ (this, i18n("Unknown proportion action %1").arg(name));
}
}
@@ -4390,7 +4390,7 @@ NotationView::slotChangeProportion(int proportion)
// m_proportionSlider->setSize(proportion);
KToggleAction *action = dynamic_cast<KToggleAction *>
- (actionCollection()->action(TQString("proportion_%1").tqarg(proportion).ascii()));
+ (actionCollection()->action(TQString("proportion_%1").arg(proportion).ascii()));
if (action)
action->setChecked(true);
else {
@@ -4422,7 +4422,7 @@ NotationView::slotChangeFontFromAction()
slotChangeFont(name);
} else {
KMessageBox::sorry
- (this, i18n("Unknown font action %1").tqarg(name));
+ (this, i18n("Unknown font action %1").arg(name));
}
}
@@ -4440,11 +4440,11 @@ NotationView::slotChangeFontSizeFromAction()
slotChangeFont(m_fontName, size);
else {
KMessageBox::sorry
- (this, i18n("Unknown font size %1").tqarg(name));
+ (this, i18n("Unknown font size %1").arg(name));
}
} else {
KMessageBox::sorry
- (this, i18n("Unknown font size action %1").tqarg(name));
+ (this, i18n("Unknown font size action %1").arg(name));
}
}
@@ -5357,7 +5357,7 @@ void NotationView::slotAddIndication(std::string type, TQString desc)
setSingleSelectedEvent(m_currentEventSelection->getSegment(),
command->getLastInsertedEvent());
} else {
- KMessageBox::sorry(this, i18n("Can't add overlapping %1 indications").tqarg(desc)); // TODO PLURAL - how many 'indications' ?
+ KMessageBox::sorry(this, i18n("Can't add overlapping %1 indications").arg(desc)); // TODO PLURAL - how many 'indications' ?
delete command;
}
}
@@ -5568,7 +5568,7 @@ void NotationView::slotSetStyleFromAction()
if (name.left(6) == "style_") {
name = name.right(name.length() - 6);
- KTmpStatusMsg msg(i18n("Changing to %1 style...").tqarg(name),
+ KTmpStatusMsg msg(i18n("Changing to %1 style...").arg(name),
this);
addCommandToHistory(new ChangeStyleCommand
@@ -5576,7 +5576,7 @@ void NotationView::slotSetStyleFromAction()
*m_currentEventSelection));
} else {
KMessageBox::sorry
- (this, i18n("Unknown style action %1").tqarg(name));
+ (this, i18n("Unknown style action %1").arg(name));
}
}
@@ -5608,7 +5608,7 @@ void NotationView::slotInsertNoteFromAction()
} catch (...) {
KMessageBox::sorry
- (this, i18n("Unknown note insert action %1").tqarg(name));
+ (this, i18n("Unknown note insert action %1").arg(name));
return ;
}
@@ -6027,9 +6027,9 @@ NotationView::slotMakeOrnament()
TQString name;
int barNo = segment.getComposition()->getBarNumber(absTime);
if (track) {
- name = TQString(i18n("Ornament track %1 bar %2").tqarg(track->getPosition() + 1).tqarg(barNo + 1));
+ name = TQString(i18n("Ornament track %1 bar %2").arg(track->getPosition() + 1).arg(barNo + 1));
} else {
- name = TQString(i18n("Ornament bar %1").tqarg(barNo + 1));
+ name = TQString(i18n("Ornament bar %1").arg(barNo + 1));
}
MakeOrnamentDialog dialog(this, name, basePitch);
@@ -6536,7 +6536,7 @@ NotationView::slotSetCurrentStaff(int staffNo)
m_chordNameRuler->setCurrentSegment(segment);
m_rawNoteRuler->setCurrentSegment(segment);
- m_rawNoteRuler->tqrepaint();
+ m_rawNoteRuler->repaint();
setControlRulersCurrentSegment();
updateView();
@@ -7194,17 +7194,17 @@ NotationView::slotHoveredOverAbsoluteTimeChanged(unsigned int time)
// TQString message;
// TQString format("%ld (%ld.%03lds)");
- // format = i18n("Time: %1").tqarg(format);
+ // format = i18n("Time: %1").arg(format);
// message.sprintf(format, t, rt.sec, ms);
TQString message = i18n("Time: %1 (%2.%3s)")
- .tqarg(TQString("%1-%2-%3-%4")
- .tqarg(TQString("%1").tqarg(bar + 1).rightJustify(3, '0'))
- .tqarg(TQString("%1").tqarg(beat).rightJustify(2, '0'))
- .tqarg(TQString("%1").tqarg(fraction).rightJustify(2, '0'))
- .tqarg(TQString("%1").tqarg(remainder).rightJustify(2, '0')))
- .tqarg(rt.sec)
- .tqarg(TQString("%1").tqarg(ms).rightJustify(3, '0'));
+ .arg(TQString("%1-%2-%3-%4")
+ .arg(TQString("%1").arg(bar + 1).rightJustify(3, '0'))
+ .arg(TQString("%1").arg(beat).rightJustify(2, '0'))
+ .arg(TQString("%1").arg(fraction).rightJustify(2, '0'))
+ .arg(TQString("%1").arg(remainder).rightJustify(2, '0')))
+ .arg(rt.sec)
+ .arg(TQString("%1").arg(ms).rightJustify(3, '0'));
m_hoveredOverAbsoluteTime->setText(message);
}
@@ -3194,7 +3194,7 @@ void NotationView::setCurrentSelection(EventSelection* s, bool preview,
std::max(endA, endB));
} else {
- // mark refresh status and then request a tqrepaint
+ // mark refresh status and then request a repaint
segment.getRefreshStatus
(m_segmentsRefreshStatusIds
@@ -3211,7 +3211,7 @@ void NotationView::setCurrentSelection(EventSelection* s, bool preview,
getLinedStaff(s->getSegment())->positionElements(startB, endB);
} else {
- // mark refresh status and then request a tqrepaint
+ // mark refresh status and then request a repaint
oldSelection->getSegment().getRefreshStatus
(m_segmentsRefreshStatusIds